| Title: | Process Logical Operations |
|---|---|
| Description: | Processing logical operations such as AND/OR/NOT operations dynamically. It also handles nesting in the operations. |
| Authors: | Sunny Kumar <[email protected]> |
| Maintainer: | Sunny Kumar <[email protected]> |
| License: | GPL |
| Version: | 0.1 |
| Built: | 2026-05-09 06:29:07 UTC |
| Source: | https://github.com/cran/RLogicalOps |
Dynamically process the logical operations over a list of string and get the result
processLogiOper(logicalOperation, stringList)processLogiOper(logicalOperation, stringList)
logicalOperation |
A String containing the logical operation to be performed |
stringList |
A list of String over which the logical operation is to be performed |
A list of the output values(0/1)
logicalOperation <- "AND(Cake,OR(Birthday,Anniversary))" stringList <- c("The cake at the birthday was awesome." ,"Their anniversary was last week.") processLogiOper(logicalOperation, stringList)logicalOperation <- "AND(Cake,OR(Birthday,Anniversary))" stringList <- c("The cake at the birthday was awesome." ,"Their anniversary was last week.") processLogiOper(logicalOperation, stringList)